@@ -9,18 +9,20 @@
 #' downloaded. It then parses all the important header information from filings.
 #' The function returns a dataframe with filing and header information. 
 #' User must follow the US SEC's fair access policy, i.e. download only what you 
-#' need and limit your request rates, see \url{https://www.sec.gov/os/accessing-edgar-data}.
+#' need and limit your request rates, see www.sec.gov/os/accessing-edgar-data.
 #' 
-#' @usage getFilingHeader(cik.no, form.type, filing.year)
+#' @usage getFilingHeader(cik.no, form.type, filing.year, useragent)
 #' 
 #' @param cik.no vector of CIK(s) in integer format. Suppress leading 
-#' zeroes from CIKs. cik.no = 'ALL' considers all the CIKs.
+#' zeroes from CIKs. cik.no = 'ALL' conisders all the CIKs.
 #'  
 #' @param form.type character vector containing form type to be downloaded. 
 #' form.type = 'ALL' if need to download all forms.  
 #'
 #' @param filing.year vector of four digit numeric year
 #' 
+#' @param useragent Should be in the form of "YourName Contact@domain.com"
+#' 
 #' @return Function returns dataframe containing CIK number, company name, 
 #' date of filing, accession number, confirmed period of report, fiscal year end,
 #' Standard Industrial Classification (SIC) code, Internal Revenue Code (IRS) 
@@ -33,16 +35,16 @@
 #' \dontrun{
 #' 
 #' header.df <- getFilingHeader(cik.no = c('1000180', '38079'), 
-#'                          form.type = '10-K', filing.year = 2006) 
+#'                          form.type = '10-K', filing.year = 2006, useragent) 
 #'               
 #' header.df <- getFilingHeader(cik.no = '38079', c('10-K', '10-Q'), 
-#'                          filing.year = c(2005, 2006))
+#'                          filing.year = c(2005, 2006), useragent)
 #'}
 
-getFilingHeader <- function(cik.no, form.type, filing.year) {
-      
+getFilingHeader <- function(cik.no, form.type, filing.year, useragent="") {
+  
     output <- getFilings(cik.no, form.type, filing.year, 
-                         quarter = c(1, 2, 3, 4), downl.permit = "y")
+                         quarter = c(1, 2, 3, 4), downl.permit = "y", useragent)
     
     if (is.null(output)) {
         # cat('Please check the CIK number.')
