@@ -14,9 +14,9 @@
 #' "edgar_searchFilings". These HTML view of search results would help the user 
 #' to analyze the search strategy and identify false positive hits. 
 #' User must follow the US SEC's fair access policy, i.e. download only what you 
-#' need and limit your request rates, see \url{https://www.sec.gov/os/accessing-edgar-data}.
+#' need and limit your request rates, see www.sec.gov/os/accessing-edgar-data.
 #' 
-#' @usage searchFilings(cik.no, form.type, filing.year, word.list)
+#' @usage searchFilings(cik.no, form.type, filing.year, word.list, useragent)
 #' 
 #' @param cik.no vector of CIK number of firms in integer format. Suppress leading 
 #' zeroes from CIKs. Keep cik.no = 'ALL' if needs to download for all CIK's.
@@ -28,24 +28,25 @@
 #' 
 #' @param word.list vector of words to search in the filing
 #' 
+#' @param useragent Should be in the form of "YourName Contact@domain.com"
 #' 
 #' @return Function returns dataframe containing filing information and the 
 #' number of word hits based on the input phrases. Additionally, this 
 #' function saves search information with surrounding content of 
-#' search keywords in HTML file in directory "edgar_searchFilings".
+#' search keywords in HTML file in directory "Keyword search results".
 #' @examples
 #' \dontrun{
 #'
 #' word.list = c('derivative','hedging','currency forwards','currency futures')
 #' output <- searchFilings(cik.no = c('1000180', '38079'), 
-#'                      form.type = c("10-K", "10-K405","10KSB", "10-KSB", "10KSB40"), 
-#'                      filing.year = c(2005, 2006), word.list) 
+#'                      form.type = c("10-K", "10-K405","10KSB", "10KSB40"), 
+#'                      filing.year = c(2005, 2006), word.list, useragent) 
 #'}
 
-searchFilings <- function(cik.no, form.type, filing.year, word.list) {
+searchFilings <- function(cik.no, form.type, filing.year, word.list, useragent = "") {
    
   output <- getFilings(cik.no, form.type, filing.year, quarter = c(1, 2, 3, 4), 
-                       downl.permit = "y")
+                       downl.permit = "y", useragent)
   
   if (is.null(output)){
     # cat("Please check the CIK number.")
